#line 2 "beancount/parser/lexer.c"
#line 23 "beancount/parser/lexer.l"

/* Includes. */
#include <math.h>
#include <stdlib.h>

#include "parser.h"
#include "grammar.h"


/* Build and accumulate an error on the builder object. */
void build_lexer_error(const char* string, size_t length);

/* Build and accumulate an error on the builder object using the current
 * exception state. */
void build_lexer_error_from_exception(void);



/* Callback call site with error handling. */
#define BUILD_LEX(method_name, format, ...)                                             \
    yylval->pyobj = PyObject_CallMethod(builder, method_name, format, __VA_ARGS__);     \
    /* Handle a Python exception raised by the handler {3cfb2739349a} */                \
    if (yylval->pyobj == NULL) {                                                        \
       build_lexer_error_from_exception();                                              \
       return LEX_ERROR;                                                                \
    }                                                                                   \
    /* Lexer builder methods should never return None, check for it. */                 \
    else if (yylval->pyobj == Py_None) {                                                \
        Py_DECREF(Py_None);                                                             \
        build_lexer_error("Unexpected None result from lexer", 34);                     \
        return LEX_ERROR;                                                               \
    }


/* Initialization/finalization methods. These are separate from the yylex_init()
 * and yylex_destroy() and they call them. */
void yylex_initialize(const char* filename, const char* encoding);
void yylex_finalize(void);


/* Global declarations; defined below. */
extern int yy_eof_times;
extern const char* yy_filename;
extern int yycolumn;
extern const char* yy_encoding;

/* String buffer statics. */
extern size_t strbuf_size; /* Current buffer size (not including final nul). */
extern char* strbuf;       /* Current buffer head. */
extern char* strbuf_end;   /* Current buffer sentinel (points to the final nul). */
extern char* strbuf_ptr;   /* Current insertion point in buffer. */
void strbuf_realloc(size_t num_new_chars);



/* Handle detecting the beginning of line. */
extern int yy_line_tokens; /* Number of tokens since the bol. */

#define YY_USER_ACTION  {                               \
    yy_line_tokens++;                                   \
    yylloc->first_line = yylloc->last_line = yylineno;  \
    yylloc->first_column = yycolumn;                    \
    yylloc->last_column = yycolumn+yyleng-1;            \
    yycolumn += yyleng;                                 \
  }


/* Skip the rest of the input line. */
int yy_skip_line(void);


/* Utility functions. */
int strtonl(const char* buf, size_t nchars);


/* Append characters to the static string buffer and verify. */
#define SAFE_COPY_CHAR(value)                    \
	if (strbuf_ptr >= strbuf_end) {         \
            strbuf_realloc(1);                  \
	}                                       \
        *strbuf_ptr++ = value;




#line 89 "beancount/parser/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 61
#define YY_END_OF_BUFFER 62
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[267] =
    {   0,
        0,    0,    0,    0,    0,    0,   62,   59,    2,    1,
       21,   46,   18,   16,   17,   19,   12,   10,   13,   14,
       55,   15,   20,    5,   59,   21,   59,   21,   59,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
        8,    3,    9,   11,   60,   61,   54,   47,   61,    2,
       56,    0,   55,   55,   20,   20,    4,    0,    0,   45,
        0,    0,   45,   45,   57,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    6,    7,   60,   54,   53,   51,   52,   48,
       50,   49,   55,   55,   55,    0,   45,    0,   45,   44,

       45,   45,   58,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   27,    0,    0,    0,    0,    0,   22,
       55,    0,   45,    0,   45,   44,   45,   41,    0,    0,
        0,    0,    0,    0,    0,   32,   24,    0,    0,    0,
        0,    0,    0,    0,    0,   55,    0,   45,    0,   45,
       42,    0,   25,    0,    0,    0,   28,    0,    0,    0,
        0,    0,   31,    0,    0,   29,    0,    0,   45,    0,
       45,    0,    0,   30,    0,    0,   38,   39,    0,   35,
        0,    0,    0,    0,   45,    0,   45,   23,    0,    0,
       40,   37,    0,   34,   43,    0,   45,    0,   45,    0,

       33,   36,    0,   45,    0,   45,   26,    0,   45,    0,
       45,    0,   45,    0,   45,    0,   45,    0,   45,    0,
       45,    0,   45,    0,   45,    0,   45,    0,   45,    0,
       45,    0,   45,    0,   45,    0,   45,    0,   45,    0,
       45,    0,   45,    0,   45,    0,   45,    0,   45,    0,
       45,    0,   45,    0,   45,    0,   45,    0,   45,    0,
       45,    0,   45,   45,   45,    0
    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    6,    1,    4,    4,    7,    8,
        9,   10,   11,   12,   13,   14,   15,   16,   16,   16,
       16,   16,   16,   16,   16,   16,   16,   17,   18,    1,
        1,    1,    4,   19,   20,   21,   22,   21,   23,   24,
       21,   21,   21,   21,   21,   25,   22,   21,   21,   22,
       21,   26,   27,   28,   29,   21,   21,   21,   21,   21,
        1,   30,    1,   31,   32,    1,   33,   34,   35,   36,

       37,   38,   39,   40,   41,   42,   42,   43,   44,   45,
       46,   47,   48,   49,   50,   51,   52,   53,   42,   54,
       55,   42,   56,   57,   58,   59,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[60] =
    {   0,
        1,    2,    3,    1,    4,    1,    5,    1,    1,    1,
        1,    1,    6,    7,    8,    9,   10,    1,    1,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    4,
        1,   11,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,   12,   12,   12,    1,    1,    1,    1
    } ;

static yyconst flex_uint16_t yy_base[300] =
    {   0,
        0,    0,   58,   60,   59,   60,  509, 1250,  501, 1250,
     1250, 1250,    0, 1250, 1250, 1250, 1250, 1250, 1250, 1250,
       54, 1250,  480,  478,   84,    0,  476,  469,    0,    0,
      459,   26,  445,  437,  444,  442,  433,   34,  426,  409,
      406, 1250,  403, 1250,    0, 1250,    0, 1250,  106,  457,
        0,   59,  438,   80,    0,  435, 1250,  134,  160,    0,
        0,  186,  427,  407,    0,  416,   56,   57,   70,   65,
       67,  125,  126,  128,  153,   59,  139,  147,  136,  146,
      132,  133, 1250, 1250,    0,    0, 1250, 1250, 1250, 1250,
     1250, 1250,  189,  414,  205,  209,  213,  239,    0,  412,

      401,  400, 1250,  135,  148,  180,  178,  217,  211,  129,
      213,  225,  208,  404,  215,  230,  216,  218,  223,  403,
      263,  273,  275,  301,    0,  398,  390,    0,  240,  256,
      266,  267,  274,  280,  282,  349,  289,  273,  275,  283,
      142,  315,  292,  284,  288,  332,  328,  342,  368,    0,
        0,  323,  286,  321,  293,  333,  285,  336,  334,  342,
      347,  337,  281,  346,  278,  279,  223,  354,  392,  418,
        0,  348,  360,  277,  363,  385,  231,  227,  345,  226,
      352,  387,  221,  403,  405,  444,    0,  214,  356,  397,
      154,  143,  394,  141,  138,  442,  468,  494,    0,  354,

       76,   71,  470,  472,  520,    0,   68,  480,  492,  546,
        0,  518,  544,  572,    0,  570,  596,  622,    0,  598,
      600,  648,    0,  608,  620,  674,    0,  646,  672,  700,
        0,  698,  724,  750,    0,  726,  728,  776,    0,  736,
      748,  802,    0,  774,  800,  828,    0,  826,  852,  878,
        0,  854,  856,  904,    0,  864,  876,  930,    0,    0,
        0,  956,    0, 1250,  973, 1250, 1002, 1014, 1021, 1033,
     1040, 1047, 1059, 1071, 1083, 1091,   72, 1098, 1104, 1112,
     1119, 1126, 1133, 1140, 1147, 1154, 1161, 1168, 1175, 1182,
     1189, 1196, 1203, 1210, 1217, 1224, 1231, 1238,   70

    } ;

static yyconst flex_int16_t yy_def[300] =
    {   0,
      266,    1,  267,  267,  268,  268,  266,  266,  266,  266,
      266,  266,  269,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  270,  266,  266,   25,   25,   25,  271,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      266,  266,  266,  266,  273,  266,  274,  266,  275,  266,
      269,  266,  266,  266,  270,  270,  266,  276,   25,   59,
      277,   59,   59,   59,  271,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  266,  266,  273,  274,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  278,  278,   59,   98,  279,

       98,   98,  266,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      266,  280,  280,   98,  124,  279,  124,  124,  272,  272,
      272,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  266,  266,  281,  281,  124,  149,
      149,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  272,  272,  272,  272,  266,  282,  282,  149,
      170,  272,  272,  272,  272,  272,  272,  272,  272,  272,
      272,  272,  266,  283,  283,  170,  186,  272,  272,  272,
      272,  272,  272,  272,  266,  284,  284,  186,  198,  272,

      272,  272,  285,  285,  198,  205,  272,  286,  286,  205,
      210,  287,  287,  210,  214,  288,  288,  214,  218,  289,
      289,  218,  222,  290,  290,  222,  226,  291,  291,  226,
      230,  292,  292,  230,  234,  293,  293,  234,  238,  294,
      294,  238,  242,  295,  295,  242,  246,  296,  296,  246,
      250,  297,  297,  250,  254,  298,  298,  254,  258,  299,
      299,  258,  262,  266,  262,    0,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266

    } ;

static yyconst flex_uint16_t yy_nxt[1310] =
    {   0,
        8,    9,   10,   11,   12,   13,    8,   14,   15,   16,
       17,   18,   19,    8,   20,   21,   22,   23,   24,   25,
       25,   26,   25,   27,   25,   26,   26,   28,   26,    8,
       29,    8,   30,   31,   32,   33,   34,   30,   30,   30,
       35,   30,   30,   30,   36,   37,   38,   39,   30,   30,
       40,   30,   30,   30,   30,   41,   42,   43,   44,   46,
       46,   46,   46,   48,   48,   52,   76,   53,   68,   54,
       52,   69,  103,  103,   93,  103,   77,   70,  264,   78,
      100,  103,   79,  103,  103,   80,  103,  103,   49,   49,
       58,   52,  103,   53,  114,   95,   59,   58,  104,   60,

       61,  108,  105,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,  106,  107,   58,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   88,
       96,  103,  103,   89,  103,  103,   96,   96,  103,  103,
       90,  103,  103,  195,   91,  103,   92,  103,  103,  103,
      110,  109,  103,  103,  103,   96,   96,  129,  119,  103,
      103,  135,   98,   96,  162,   99,  117,  120,  111,   99,
       99,   99,   99,   99,   99,   99,   99,   99,   99,  112,
      115,   96,  266,  116,  103,  118,  103,  130,   62,  266,

       52,   62,   53,  113,   93,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,  122,   52,  266,   53,  122,
      121,  122,  122,  131,  103,  122,  122,  103,  132,  103,
      103,  103,  103,  103,  103,  183,  195,  183,  167,  103,
      122,  103,  103,  103,  122,  122,  103,  103,  138,  136,
      142,  124,  122,  139,  125,  134,  103,  143,  125,  125,
      125,  125,  125,  125,  125,  125,  125,  125,  133,  137,
      122,  144,  103,  140,   52,  145,   53,  145,  146,  147,
      141,  147,  103,  103,  152,  147,  147,  147,  147,  103,
      103,  103,  153,  103,  103,  103,  103,  103,  103,  103,

      103,  103,  103,  167,  147,  103,  147,  147,  103,  103,
      182,  154,  155,  149,  147,  160,  150,  156,  159,  161,
      150,  150,  150,  150,  150,  150,  150,  150,  150,  150,
      157,  103,  147,  158,  168,  164,  174,  103,  166,  103,
      168,  168,  165,   52,  145,   53,  145,  146,  168,  103,
      103,  163,  103,  103,  168,  168,  173,  172,  103,  168,
      184,  103,  103,  103,  103,  103,  184,  184,  103,  175,
      103,  176,  103,  168,  168,  180,  103,  192,  177,  103,
      170,  168,  181,  171,  188,  184,  178,  171,  171,  171,
      171,  171,  171,  171,  171,  171,  171,  179,  184,  168,

      189,  103,  193,  103,  184,  184,  200,  190,  207,  196,
      103,  196,  151,  103,   61,  196,  196,  196,  196,  103,
      103,  191,  128,  184,  184,  194,  202,  127,   61,   94,
      186,  184,  103,  187,  196,  102,  196,  187,  187,  187,
      187,  187,  187,  187,  187,  187,  187,  201,  203,  184,
      196,  101,   56,   94,  203,  203,  198,  196,   50,  199,
       84,   83,   82,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  203,  203,  196,  208,   81,  208,   75,
      203,  203,  208,  208,  208,  208,  212,   74,   73,   72,
       71,   67,  212,  212,   64,   63,   57,   56,  212,  203,

      203,  208,   50,  208,  212,  212,  205,  203,  266,  206,
      266,  212,  266,  206,  206,  206,  206,  206,  206,  206,
      206,  206,  206,  212,  216,  203,  208,  266,  266,  266,
      216,  216,  210,  208,  266,  211,  266,  266,  266,  211,
      211,  211,  211,  211,  211,  211,  211,  211,  211,  216,
      216,  208,  212,  266,  266,  266,  216,  216,  214,  212,
      266,  215,  266,  266,  266,  215,  215,  215,  215,  215,
      215,  215,  215,  215,  215,  216,  220,  212,  216,  266,
      266,  266,  220,  220,  218,  216,  266,  219,  266,  266,
      266,  219,  219,  219,  219,  219,  219,  219,  219,  219,

      219,  220,  220,  216,  224,  266,  224,  266,  220,  220,
      224,  224,  224,  224,  228,  266,  266,  266,  266,  266,
      228,  228,  266,  266,  266,  266,  228,  220,  220,  224,
      266,  224,  228,  228,  222,  220,  266,  223,  266,  228,
      266,  223,  223,  223,  223,  223,  223,  223,  223,  223,
      223,  228,  232,  220,  224,  266,  266,  266,  232,  232,
      226,  224,  266,  227,  266,  266,  266,  227,  227,  227,
      227,  227,  227,  227,  227,  227,  227,  232,  232,  224,
      228,  266,  266,  266,  232,  232,  230,  228,  266,  231,
      266,  266,  266,  231,  231,  231,  231,  231,  231,  231,

      231,  231,  231,  232,  236,  228,  232,  266,  266,  266,
      236,  236,  234,  232,  266,  235,  266,  266,  266,  235,
      235,  235,  235,  235,  235,  235,  235,  235,  235,  236,
      236,  232,  240,  266,  240,  266,  236,  236,  240,  240,
      240,  240,  244,  266,  266,  266,  266,  266,  244,  244,
      266,  266,  266,  266,  244,  236,  236,  240,  266,  240,
      244,  244,  238,  236,  266,  239,  266,  244,  266,  239,
      239,  239,  239,  239,  239,  239,  239,  239,  239,  244,
      248,  236,  240,  266,  266,  266,  248,  248,  242,  240,
      266,  243,  266,  266,  266,  243,  243,  243,  243,  243,

      243,  243,  243,  243,  243,  248,  248,  240,  244,  266,
      266,  266,  248,  248,  246,  244,  266,  247,  266,  266,
      266,  247,  247,  247,  247,  247,  247,  247,  247,  247,
      247,  248,  252,  244,  248,  266,  266,  266,  252,  252,
      250,  248,  266,  251,  266,  266,  266,  251,  251,  251,
      251,  251,  251,  251,  251,  251,  251,  252,  252,  248,
      256,  266,  256,  266,  252,  252,  256,  256,  256,  256,
      260,  266,  266,  266,  266,  266,  260,  260,  266,  266,
      266,  266,  260,  252,  252,  256,  266,  256,  260,  260,
      254,  252,  266,  255,  266,  260,  266,  255,  255,  255,

      255,  255,  255,  255,  255,  255,  255,  260,  266,  252,
      256,  266,  266,  266,  266,  266,  258,  256,  266,  259,
      266,  266,  266,  259,  259,  259,  259,  259,  259,  259,
      259,  259,  259,  266,  266,  256,  260,  266,  266,  266,
      266,  266,  262,  260,  266,  263,  266,  266,  266,  263,
      263,  263,  263,  263,  263,  263,  263,  263,  263,  266,
      266,  260,  266,  266,  266,  266,  266,  266,   62,  266,
      266,  265,  266,  266,  266,  265,  265,  265,  265,  265,
      265,  265,  265,  265,  265,  266,  266,  266,   62,  266,
      266,  266,   62,   62,   62,   62,   62,   62,   62,   62,

       62,   62,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   47,   47,   47,   51,   51,   51,   51,
      266,   51,   51,   55,   55,  266,   55,   55,   55,   55,
       55,   55,   55,   55,   55,   65,   65,   65,   65,  266,
       65,   65,   66,  266,  266,   66,  266,   66,   66,   85,
      266,  266,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   86,   86,   86,  266,   86,   86,   86,   86,   86,
       86,   86,   86,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   97,   97,   97,  266,   97,

      266,   97,  123,  123,  123,  266,  123,  266,  123,  126,
      266,  266,  126,  126,  266,  126,  148,  148,  148,  266,
      148,  266,  148,  169,  169,  169,  266,  169,  266,  169,
      185,  185,  185,  266,  185,  266,  185,  197,  197,  197,
      266,  197,  266,  197,  204,  204,  204,  266,  204,  266,
      204,  209,  209,  209,  266,  209,  266,  209,  213,  213,
      213,  266,  213,  266,  213,  217,  217,  217,  266,  217,
      266,  217,  221,  221,  221,  266,  221,  266,  221,  225,
      225,  225,  266,  225,  266,  225,  229,  229,  229,  266,
      229,  266,  229,  233,  233,  233,  266,  233,  266,  233,

      237,  237,  237,  266,  237,  266,  237,  241,  241,  241,
      266,  241,  266,  241,  245,  245,  245,  266,  245,  266,
      245,  249,  249,  249,  266,  249,  266,  249,  253,  253,
      253,  266,  253,  266,  253,  257,  257,  257,  266,  257,
      266,  257,  261,  261,  261,  266,  261,  266,  261,    7,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,

      266,  266,  266,  266,  266,  266,  266,  266,  266
    } ;

static yyconst flex_int16_t yy_chk[1310] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    3,
        3,    4,    4,    5,    6,   21,   38,   21,   32,   21,
       52,   32,   67,   68,   52,   76,   38,   32,  299,   38,
      277,   70,   38,   71,  207,   38,   69,  202,    5,    6,
       25,   54,  201,   54,   76,   54,   25,   25,   67,   25,

       25,   71,   68,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   69,   70,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   25,
       25,   25,   25,   25,   25,   25,   25,   25,   25,   49,
       58,   72,   73,   49,   74,  110,   58,   58,   81,   82,
       49,  104,   79,  195,   49,   77,   49,  194,  141,  192,
       73,   72,   80,   78,  105,   58,   59,  104,   81,   75,
      191,  110,   59,   59,  141,   59,   79,   82,   74,   59,
       59,   59,   59,   59,   59,   59,   59,   59,   59,   75,
       77,   59,   62,   78,  107,   80,  106,  105,   62,   62,

       93,   62,   93,   75,   93,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   96,   95,   62,   95,   97,
       95,   96,   96,  106,  113,   97,   97,  109,  107,  111,
      188,  115,  117,  108,  118,  167,  183,  167,  167,  119,
       96,  112,  180,  178,   97,   98,  116,  177,  113,  111,
      117,   98,   98,  115,   98,  109,  129,  118,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,  108,  112,
       98,  119,  130,  116,  121,  121,  121,  121,  121,  122,
      116,  123,  131,  132,  129,  122,  122,  123,  123,  138,
      133,  139,  130,  174,  165,  166,  134,  163,  135,  140,

      144,  157,  153,  145,  122,  137,  123,  124,  143,  155,
      165,  131,  132,  124,  124,  139,  124,  133,  138,  140,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  124,
      134,  142,  124,  135,  147,  143,  155,  154,  144,  152,
      147,  147,  143,  146,  146,  146,  146,  146,  148,  156,
      159,  142,  158,  162,  148,  148,  154,  152,  160,  147,
      168,  179,  164,  161,  172,  136,  168,  168,  181,  156,
      200,  158,  189,  148,  149,  162,  173,  179,  159,  175,
      149,  149,  164,  149,  172,  168,  160,  149,  149,  149,
      149,  149,  149,  149,  149,  149,  149,  161,  169,  149,

      173,  176,  181,  182,  169,  169,  189,  175,  200,  184,
      193,  185,  127,  190,  126,  184,  184,  185,  185,  120,
      114,  176,  102,  169,  170,  182,  193,  101,  100,   94,
      170,  170,   66,  170,  184,   64,  185,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  190,  196,  170,
      186,   63,   56,   53,  196,  196,  186,  186,   50,  186,
       43,   41,   40,  186,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  196,  197,  186,  203,   39,  204,   37,
      197,  197,  203,  203,  204,  204,  208,   36,   35,   34,
       33,   31,  208,  208,   28,   27,   24,   23,  209,  197,

      198,  203,    9,  204,  209,  209,  198,  198,    7,  198,
        0,  208,    0,  198,  198,  198,  198,  198,  198,  198,
      198,  198,  198,  209,  212,  198,  205,    0,    0,    0,
      212,  212,  205,  205,    0,  205,    0,    0,    0,  205,
      205,  205,  205,  205,  205,  205,  205,  205,  205,  212,
      213,  205,  210,    0,    0,    0,  213,  213,  210,  210,
        0,  210,    0,    0,    0,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  213,  216,  210,  214,    0,
        0,    0,  216,  216,  214,  214,    0,  214,    0,    0,
        0,  214,  214,  214,  214,  214,  214,  214,  214,  214,

      214,  216,  217,  214,  220,    0,  221,    0,  217,  217,
      220,  220,  221,  221,  224,    0,    0,    0,    0,    0,
      224,  224,    0,    0,    0,    0,  225,  217,  218,  220,
        0,  221,  225,  225,  218,  218,    0,  218,    0,  224,
        0,  218,  218,  218,  218,  218,  218,  218,  218,  218,
      218,  225,  228,  218,  222,    0,    0,    0,  228,  228,
      222,  222,    0,  222,    0,    0,    0,  222,  222,  222,
      222,  222,  222,  222,  222,  222,  222,  228,  229,  222,
      226,    0,    0,    0,  229,  229,  226,  226,    0,  226,
        0,    0,    0,  226,  226,  226,  226,  226,  226,  226,

      226,  226,  226,  229,  232,  226,  230,    0,    0,    0,
      232,  232,  230,  230,    0,  230,    0,    0,    0,  230,
      230,  230,  230,  230,  230,  230,  230,  230,  230,  232,
      233,  230,  236,    0,  237,    0,  233,  233,  236,  236,
      237,  237,  240,    0,    0,    0,    0,    0,  240,  240,
        0,    0,    0,    0,  241,  233,  234,  236,    0,  237,
      241,  241,  234,  234,    0,  234,    0,  240,    0,  234,
      234,  234,  234,  234,  234,  234,  234,  234,  234,  241,
      244,  234,  238,    0,    0,    0,  244,  244,  238,  238,
        0,  238,    0,    0,    0,  238,  238,  238,  238,  238,

      238,  238,  238,  238,  238,  244,  245,  238,  242,    0,
        0,    0,  245,  245,  242,  242,    0,  242,    0,    0,
        0,  242,  242,  242,  242,  242,  242,  242,  242,  242,
      242,  245,  248,  242,  246,    0,    0,    0,  248,  248,
      246,  246,    0,  246,    0,    0,    0,  246,  246,  246,
      246,  246,  246,  246,  246,  246,  246,  248,  249,  246,
      252,    0,  253,    0,  249,  249,  252,  252,  253,  253,
      256,    0,    0,    0,    0,    0,  256,  256,    0,    0,
        0,    0,  257,  249,  250,  252,    0,  253,  257,  257,
      250,  250,    0,  250,    0,  256,    0,  250,  250,  250,

      250,  250,  250,  250,  250,  250,  250,  257,    0,  250,
      254,    0,    0,    0,    0,    0,  254,  254,    0,  254,
        0,    0,    0,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,    0,    0,  254,  258,    0,    0,    0,
        0,    0,  258,  258,    0,  258,    0,    0,    0,  258,
      258,  258,  258,  258,  258,  258,  258,  258,  258,    0,
        0,  258,  262,    0,    0,    0,    0,    0,  262,  262,
        0,  262,    0,    0,    0,  262,  262,  262,  262,  262,
      262,  262,  262,  262,  262,    0,    0,  262,  265,    0,
        0,    0,  265,  265,  265,  265,  265,  265,  265,  265,

      265,  265,  267,  267,  267,  267,  267,  267,  267,  267,
      267,  267,  267,  267,  268,  268,  268,  268,  268,  268,
      268,  268,  268,  268,  268,  268,  269,  269,  269,  269,
        0,  269,  269,  270,  270,    0,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  271,  271,  271,  271,    0,
      271,  271,  272,    0,    0,  272,    0,  272,  272,  273,
        0,    0,  273,  273,  273,  273,  273,  273,  273,  273,
      273,  274,  274,  274,    0,  274,  274,  274,  274,  274,
      274,  274,  274,  275,  275,  275,  275,  275,  275,  275,
      275,  275,  275,  275,  275,  276,  276,  276,    0,  276,

        0,  276,  278,  278,  278,    0,  278,    0,  278,  279,
        0,    0,  279,  279,    0,  279,  280,  280,  280,    0,
      280,    0,  280,  281,  281,  281,    0,  281,    0,  281,
      282,  282,  282,    0,  282,    0,  282,  283,  283,  283,
        0,  283,    0,  283,  284,  284,  284,    0,  284,    0,
      284,  285,  285,  285,    0,  285,    0,  285,  286,  286,
      286,    0,  286,    0,  286,  287,  287,  287,    0,  287,
        0,  287,  288,  288,  288,    0,  288,    0,  288,  289,
      289,  289,    0,  289,    0,  289,  290,  290,  290,    0,
      290,    0,  290,  291,  291,  291,    0,  291,    0,  291,

      292,  292,  292,    0,  292,    0,  292,  293,  293,  293,
        0,  293,    0,  293,  294,  294,  294,    0,  294,    0,
      294,  295,  295,  295,    0,  295,    0,  295,  296,  296,
      296,    0,  296,    0,  296,  297,  297,  297,    0,  297,
        0,  297,  298,  298,  298,    0,  298,    0,  298,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,
      266,  266,  266,  266,  266,  266,  266,  266,  266,  266,

      266,  266,  266,  266,  266,  266,  266,  266,  266
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[62] =
    {   0,
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 
    0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "beancount/parser/lexer.l"
/* -*- mode: c -*- */
/* A flex lexer for Beancount. */
/*--------------------------------------------------------------------------------------*/
/* Definitions */
/* Options */
/* %option nodefault */
/* %option reentrant */
/* %option debug */
/* %option stack */
/* %option 8bit */
/* Top Code. */

/* A start condition for chomping an invalid token. */

/* Exclusive start condition for parsing escape sequences in string literals. */

/*--------------------------------------------------------------------------------------*/
/* Rules */
#line 982 "beancount/parser/lexer.c"

#define INITIAL 0
#define INVALID 1
#define STRLIT 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * _in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * _out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int _line_number  );

YYSTYPE * yyget_lval (void );

void yyset_lval (YYSTYPE * yylval_param  );

       YYLTYPE *yyget_lloc (void );
    
        void yyset_lloc (YYLTYPE * yylloc_param  );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput (int c,char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param );

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
        YYSTYPE * yylval;
    
        YYLTYPE * yylloc;
    
    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	{
#line 116 "beancount/parser/lexer.l"



 /* Newlines are output as explicit tokens, because lines matter in the syntax. */
#line 1225 "beancount/parser/lexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 267 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 266 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 120 "beancount/parser/lexer.l"
{
    yy_line_tokens = 0;
    yycolumn = 1;
    return EOL;
}
	YY_BREAK
/* Ignore whitespace, except when found at the beginning of a line and followed
    by a non-comment regular character. This is how we detect an initial indent
    and thus group postings together in the grammar. */
case 2:
YY_RULE_SETUP
#line 129 "beancount/parser/lexer.l"
{
    if ( yy_line_tokens == 1 ) {
        /* If the next character completes the line, skip it. */
        if ( yy_hold_char == '\n' ||
             yy_hold_char == '\r' ||
             yy_hold_char == '\0' ||
             yy_hold_char == ';' ) {
            return SKIPPED;
        }
        else {
            return INDENT;
        }
    }
}
	YY_BREAK
/* Characters with special meanings have their own tokens. */
case 3:
YY_RULE_SETUP
#line 145 "beancount/parser/lexer.l"
{ return PIPE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 146 "beancount/parser/lexer.l"
{ return ATAT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 147 "beancount/parser/lexer.l"
{ return AT; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 148 "beancount/parser/lexer.l"
{ return LCURLCURL; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 149 "beancount/parser/lexer.l"
{ return RCURLCURL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 150 "beancount/parser/lexer.l"
{ return LCURL; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 151 "beancount/parser/lexer.l"
{ return RCURL; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 152 "beancount/parser/lexer.l"
{ return COMMA; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 153 "beancount/parser/lexer.l"
{ return TILDE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 154 "beancount/parser/lexer.l"
{ return PLUS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 155 "beancount/parser/lexer.l"
{ return MINUS; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 156 "beancount/parser/lexer.l"
{ return SLASH; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 157 "beancount/parser/lexer.l"
{ return COLON; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 158 "beancount/parser/lexer.l"
{ return LPAREN; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 159 "beancount/parser/lexer.l"
{ return RPAREN; }
	YY_BREAK
/* Special handling for characters beginning a line to be ignored.
  * I'd like to improve how this is handled. Needs own lexer, really. */
case 18:
YY_RULE_SETUP
#line 163 "beancount/parser/lexer.l"
{
    if ( yy_line_tokens != 1 ) {
        return HASH;
    }
    else {
        /* Allow org-mode titles. */
        yy_skip_line();
        return SKIPPED;
    }
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 174 "beancount/parser/lexer.l"
{
    if ( yy_line_tokens != 1 ) {
        return ASTERISK;
    }
    else {
        /* Allow org-mode titles. */
        yy_skip_line();
        return SKIPPED;
    }
}
	YY_BREAK
/* Skip commented output (but not the accompanying newline). */
case 20:
YY_RULE_SETUP
#line 186 "beancount/parser/lexer.l"
{
    /* yy_skip_line(); */
    return COMMENT;
}
	YY_BREAK
/* Special characters which may be used in-lieu of a 'txn' keyword in a
    transaction declaration output as a token. Other lines are just skipped.
    This allows us to use org-mode or other separators in the input syntax.

    Note: You need to make sure to include all the values from
    beancount.core.flags, in order for round-trips between text and entries to
    be possible. {5307d8fa1e7b}
    */
case 21:
YY_RULE_SETUP
#line 199 "beancount/parser/lexer.l"
{
    if ( yy_line_tokens != 1 ) {
        yylval->character = yytext[0];
        return FLAG;
    }
    else {
        yy_skip_line();
        return SKIPPED;
    }
}
	YY_BREAK
/* Keywords. */
case 22:
YY_RULE_SETUP
#line 211 "beancount/parser/lexer.l"
{ return TXN; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 212 "beancount/parser/lexer.l"
{ return BALANCE; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 213 "beancount/parser/lexer.l"
{ return OPEN; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 214 "beancount/parser/lexer.l"
{ return CLOSE; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 215 "beancount/parser/lexer.l"
{ return COMMODITY; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 216 "beancount/parser/lexer.l"
{ return PAD; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 217 "beancount/parser/lexer.l"
{ return EVENT; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 218 "beancount/parser/lexer.l"
{ return QUERY; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 219 "beancount/parser/lexer.l"
{ return CUSTOM; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 220 "beancount/parser/lexer.l"
{ return PRICE; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 221 "beancount/parser/lexer.l"
{ return NOTE; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 222 "beancount/parser/lexer.l"
{ return DOCUMENT; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 223 "beancount/parser/lexer.l"
{ return PUSHTAG; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 224 "beancount/parser/lexer.l"
{ return POPTAG; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 225 "beancount/parser/lexer.l"
{ return PUSHMETA; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 226 "beancount/parser/lexer.l"
{ return POPMETA; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 227 "beancount/parser/lexer.l"
{ return OPTION; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 228 "beancount/parser/lexer.l"
{ return PLUGIN; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 229 "beancount/parser/lexer.l"
{ return INCLUDE; }
	YY_BREAK
/* Boolean values. */
case 41:
YY_RULE_SETUP
#line 232 "beancount/parser/lexer.l"
{
    yylval->pyobj = Py_True;
    Py_INCREF(Py_True);
    return BOOL;
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 238 "beancount/parser/lexer.l"
{
    yylval->pyobj = Py_False;
    Py_INCREF(Py_False);
    return BOOL;
}
	YY_BREAK
/* Dates. */
case 43:
YY_RULE_SETUP
#line 245 "beancount/parser/lexer.l"
{
    const char* year_str;
    const char* month_str;
    const char* day_str;
    int year, month, day;

    /* Parse the numbers. */
    year_str = yytext;
    month_str = strpbrk(year_str, "-/");
    year = strtonl(year_str, month_str - year_str);
    month_str++;
    day_str = strpbrk(month_str, "-/");
    month = strtonl(month_str, day_str - month_str);
    day_str++;
    day = strtonl(day_str, yytext + yyleng - day_str);

    /* Attempt to create the date. */
    BUILD_LEX("DATE", "iii", year, month, day);
    return DATE;
}
	YY_BREAK
/* Account names. */
case 44:
YY_RULE_SETUP
#line 267 "beancount/parser/lexer.l"
{
    BUILD_LEX("ACCOUNT", "s", yytext);
    return ACCOUNT;
}
	YY_BREAK
/* Currencies. These are defined as uppercase only in order to disambiguate the
  * syntax. This is kept in sync with beancount.core.amount.CURRENCY_RE. */
case 45:
YY_RULE_SETUP
#line 274 "beancount/parser/lexer.l"
{
    BUILD_LEX("CURRENCY", "s", yytext);
    return CURRENCY;
}
	YY_BREAK
/* String literals. */
/* Note that we use an exclusive start condition.
    See section "Start Conditions" in the GNU Flex manual. */
case 46:
YY_RULE_SETUP
#line 282 "beancount/parser/lexer.l"
{
    strbuf_ptr = strbuf;
    BEGIN(STRLIT);
}
	YY_BREAK

/* Saw closing quote - all done. */
case 47:
YY_RULE_SETUP
#line 290 "beancount/parser/lexer.l"
{
        BEGIN(INITIAL);
        *strbuf_ptr = '\0';
        PyObject* unicode_str = PyUnicode_Decode(strbuf, strbuf_ptr - strbuf,
                                                 yy_encoding, "ignore");
        if ( unicode_str == NULL ) {
            build_lexer_error_from_exception();
            yylval->pyobj = Py_None;
            Py_INCREF(Py_None);
            return LEX_ERROR;
        }
        BUILD_LEX("STRING", "O", unicode_str);
        Py_DECREF(unicode_str);
        strbuf_ptr = NULL;
        return STRING;
    }
	YY_BREAK
/* Escape sequences. */
case 48:
YY_RULE_SETUP
#line 308 "beancount/parser/lexer.l"
SAFE_COPY_CHAR('\n');
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 309 "beancount/parser/lexer.l"
SAFE_COPY_CHAR('\t');
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 310 "beancount/parser/lexer.l"
SAFE_COPY_CHAR('\r');
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 311 "beancount/parser/lexer.l"
SAFE_COPY_CHAR('\b');
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 312 "beancount/parser/lexer.l"
SAFE_COPY_CHAR('\f');
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 313 "beancount/parser/lexer.l"
SAFE_COPY_CHAR(yytext[1]);
	YY_BREAK
/* All other characters. */
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 316 "beancount/parser/lexer.l"
{
        if ( yyleng > (yy_size_t)(strbuf_end - strbuf_ptr) ) {
            strbuf_realloc(yyleng);
        }
        size_t i;
        for (i = 0; i < yyleng; ++i) {
            *strbuf_ptr++ = yytext[i];
        }
    }
	YY_BREAK

/* Numbers */
case 55:
YY_RULE_SETUP
#line 328 "beancount/parser/lexer.l"
{
    BUILD_LEX("NUMBER", "s", yytext);
    return NUMBER;
}
	YY_BREAK
/* Tags */
case 56:
YY_RULE_SETUP
#line 334 "beancount/parser/lexer.l"
{
    BUILD_LEX("TAG", "s", &(yytext[1]));
    return TAG;
}
	YY_BREAK
/* Links */
case 57:
YY_RULE_SETUP
#line 340 "beancount/parser/lexer.l"
{
    BUILD_LEX("LINK", "s", &(yytext[1]));
    return LINK;
}
	YY_BREAK
/* Key */
case 58:
YY_RULE_SETUP
#line 346 "beancount/parser/lexer.l"
{
    BUILD_LEX("KEY", "s#", yytext, yyleng-1);
    unput(':');
    return KEY;
}
	YY_BREAK
/* Default rule. {bf253a29a820} */
case 59:
YY_RULE_SETUP
#line 353 "beancount/parser/lexer.l"
{
    unput(*yytext);
    BEGIN(INVALID);
}
	YY_BREAK
/* Fake an EOL at the end of file, to ensure that files without a final newline
  * will process postings right. */
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(INVALID):
case YY_STATE_EOF(STRLIT):
#line 360 "beancount/parser/lexer.l"
{
  if ( yy_eof_times == 0 ) {
    yy_eof_times = 1;
    yylloc->first_line = yylineno;
    return EOL;
  }
  return 0;
}
	YY_BREAK
/* Note: We use a subparser here because if we set a default rule to chomp this
    pattern, it would take precedence over valid rules if the matched text is
    longer and thus would break the lexer. Writing our own lexer would fix
    this and more. {bba169a1d35a} */
case 60:
YY_RULE_SETUP
#line 373 "beancount/parser/lexer.l"
{
    char buffer[256];
    size_t length = snprintf(buffer, 256, "Invalid token: '%s'", yytext);
    build_lexer_error(buffer, length);
    BEGIN(INITIAL);
    return LEX_ERROR;
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 382 "beancount/parser/lexer.l"
ECHO;
	YY_BREAK
#line 1777 "beancount/parser/lexer.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 267 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 267 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 266);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		yy_size_t number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; // After all that talk, this was set to 1 anyways...
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
			(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 382 "beancount/parser/lexer.l"


/*--------------------------------------------------------------------------------------*/
/* User Code */


/* Note: All these globals should be moved to an yylex_extra */

/* The number of times EOF has been hit. This is used to synthesize an EOL at
 * the end of the file. */
int yy_eof_times = 0;

/* The filename being tokenized. */
const char* yy_filename = 0;

/* Number of tokens since the beginning of the line. */
int yy_line_tokens = 0;

/* The current column we're tokenizing at. */
int yycolumn = 1;

/* The encoding to use for converting strings. */
const char* yy_encoding = NULL;

/* A buffer for parsing string literals. It is reused and its size is dynamically allocated. */
size_t strbuf_size = 0;
char* strbuf = NULL;
char* strbuf_end;
char* strbuf_ptr;

/* Initialize the globals before running the lexer. */
void yylex_initialize(const char* filename, const char* encoding)
{
    assert(filename != NULL);
    yy_eof_times = 0;
    yy_filename = filename;
    yy_line_tokens = 0;
    yycolumn = 1;
    if ( encoding == 0 ) {
        yy_encoding = "utf8";
    }
    else {
        yy_encoding = encoding;
    }

    /* Start with a decent small buffer. */
    strbuf_size = 1024;
    strbuf = realloc(strbuf, strbuf_size + 1);
    strbuf_end = strbuf + strbuf_size - 1;
    strbuf_ptr = NULL;

    /* Note: If we used a reentrant parser, this routine should eventually call
     * yylex_init(). */
}

/* Finalize the globals before running the lexer. */
void yylex_finalize(void)
{
    yy_filename = NULL;

    /* Finalize our reading buffer. */
    if ( strbuf != NULL ) {
        free(strbuf);
        strbuf = NULL;
    }

    /* Call the yylex finalization routine. */
    yylex_destroy();
}


/* Reallocate the buffer to accomodate some new characters. */
void strbuf_realloc(size_t num_new_chars)
{
    assert(strbuf_ptr != NULL);
    size_t cur_size = strbuf_ptr - strbuf;
    size_t new_size = cur_size + num_new_chars;
    while ( strbuf_size < new_size ) {
        strbuf_size <<= 1;
    }
    strbuf = realloc(strbuf, strbuf_size + 1);
    strbuf_ptr = strbuf + cur_size;
    strbuf_end = strbuf + strbuf_size - 1;
}




#define LEXEOF 0

int yy_skip_line()
{
    int num_chars = 0;
    for ( ;; ) {
        int c = input();
        num_chars++;
        if ( c == LEXEOF || c == -1 ) {
            break;
        }
        if ( c == '\n' ) {
            unput(c);
            num_chars--;
            break;
        }
    }
    return num_chars;
}

/* Convert an integer string to a number. */
int strtonl(const char* buf, size_t nchars)
{
    int result = 0;
    size_t i;
    for ( i = 0; i < nchars; ++i ) {
        result *= 10;
        result += (buf[i] - '0');
    }
    return result;
}

/* Build and accumulate an error on the builder object. */
void build_lexer_error(const char* string, size_t length)
{
    TRACE_ERROR("Invalid Token");

    /* Build and accumulate a new error object. {27d1d459c5cd} */
    PyObject* rv = PyObject_CallMethod(builder, "build_lexer_error",
                                       "s#", string, length);
    if (rv == NULL) {
        PyErr_SetString(PyExc_RuntimeError,
                        "Internal error: Building exception from default rule");
    }
    Py_XDECREF(rv);
}

void build_lexer_error_from_exception()
{
    TRACE_ERROR("Lexer Builder Exception");

    /* Get the exception context. */
    PyObject* ptype = NULL;
    PyObject* pvalue = NULL;
    PyObject* ptraceback = NULL;
    PyErr_Fetch(&ptype, &pvalue, &ptraceback);
    PyErr_NormalizeException(&ptype, &pvalue, &ptraceback);

    /* Clear the exception. */
    PyErr_Clear();

    if (pvalue != NULL) {
        /* Build and accumulate a new error object. {27d1d459c5cd} */
        PyObject* rv = PyObject_CallMethod(builder, "build_lexer_error",
                                           "OO", pvalue, ptype);
        Py_XDECREF(ptype);
        Py_XDECREF(pvalue);
        Py_XDECREF(ptraceback);

        if (rv == NULL) {
            PyErr_SetString(PyExc_RuntimeError,
                            "Internal error: While building exception");
        }
    }
    else {
        PyErr_SetString(PyExc_RuntimeError,
                        "Internal error: No exception");
    }
}

